@@ -39,13 +39,8 @@ def service_is_running(servicename):
     Does not need to run as root.
     """
     try:
-        if is_systemd_running():
-            subprocess.run(['systemctl', 'status', servicename], check=True,
-                           stdout=subprocess.DEVNULL)
-        else:
-            subprocess.run(['service', servicename, 'status'], check=True,
-                           stdout=subprocess.DEVNULL)
-
+        subprocess.run(['systemctl', 'status', servicename], check=True,
+                       stdout=subprocess.DEVNULL)
         return True
     except subprocess.CalledProcessError:
         # If a service is not running we get a status code != 0 and
@@ -53,6 +48,20 @@ def service_is_running(servicename):
         return False
 
 
+@contextmanager
+def service_ensure_running(service_name):
+    """Ensure a service is running and return to previous state."""
+    starting_state = service_is_running(service_name)
+    if not starting_state:
+        service_enable(service_name)
+
+    try:
+        yield starting_state
+    finally:
+        if not starting_state:
+            service_disable(service_name)
+
+
 def service_is_enabled(service_name, strict_check=False):
     """Check if service is enabled in systemd.
 
@@ -126,12 +135,8 @@ def service_reload(service_name):
 
 def service_action(service_name, action):
     """Perform the given action on the service_name."""
-    if is_systemd_running():
-        subprocess.run(['systemctl', action, service_name],
-                       stdout=subprocess.DEVNULL, check=False)
-    else:
-        subprocess.run(['service', service_name, action],
-                       stdout=subprocess.DEVNULL, check=False)
+    subprocess.run(['systemctl', action, service_name],
+                   stdout=subprocess.DEVNULL, check=False)
 
 
 def webserver_is_enabled(name, kind='config'):
@@ -284,7 +289,7 @@ def uwsgi_disable(config_name):
     service_start('uwsgi')
 
 
-def get_addresses():
+def get_addresses() -> list[dict[str, str | bool]]:
     """Return a list of IP addresses and hostnames."""
     addresses = get_ip_addresses()
 
@@ -318,14 +323,14 @@ def get_addresses():
     return addresses
 
 
-def get_ip_addresses():
+def get_ip_addresses() -> list[dict[str, str | bool]]:
     """Return a list of IP addresses assigned to the system."""
     addresses = []
 
     output = subprocess.check_output(['ip', '-o', 'addr'])
     for line in output.decode().splitlines():
         parts = line.split()
-        address = {
+        address: dict[str, str | bool] = {
             'kind': '4' if parts[2] == 'inet' else '6',
             'address': parts[3].split('/')[0],
             'url_address': parts[3].split('/')[0],
@@ -405,21 +410,12 @@ def is_disk_image():
 
 def run_apt_command(arguments):
     """Run apt-get with provided arguments."""
-    # Ask apt-get to output its progress to file descriptor 3.
-    command = [
-        'apt-get', '--assume-yes', '--quiet=2', '--option', 'APT::Status-Fd=3'
-    ] + arguments
+    command = ['apt-get', '--assume-yes', '--quiet=2'] + arguments
 
-    # Duplicate stdout to file descriptor 3 for this process.
-    os.dup2(1, 3)
-
-    # Pass on file descriptor 3 instead of closing it.  Close stdout
-    # so that regular output is ignored.
     env = os.environ.copy()
     env['DEBIAN_FRONTEND'] = 'noninteractive'
     process = subprocess.run(command, stdin=subprocess.DEVNULL,
-                             stdout=subprocess.DEVNULL, close_fds=False,
-                             env=env, check=False)
+                             stdout=subprocess.DEVNULL, env=env, check=False)
     return process.returncode
 
 
@@ -491,3 +487,71 @@ def is_package_manager_busy():
         return True
     except subprocess.CalledProcessError:
         return False
+
+
+def podman_run(network_name, subnet, bridge_ip, host_port, container_port,
+               container_ip, volume_name, container_name, image_name,
+               extra_run_options=None, extra_network_options=None):
+    """Remove, recreate and run a podman container."""
+    try:
+        service_stop(container_name)
+        subprocess.run(['podman', 'network', 'rm', '--force', network_name],
+                       check=False)
+    finally:
+        network_create_command = [
+            'podman', 'network', 'create', '--driver', 'bridge', '--subnet',
+            subnet, '--gateway', bridge_ip, '--dns', bridge_ip,
+            '--interface-name', network_name, network_name
+        ]
+        if extra_network_options:
+            network_create_command.extend(extra_network_options)
+        # create bridge network
+        subprocess.run(network_create_command, check=True)
+
+        run_command = [
+            'podman',
+            'run',
+            '--detach',
+            # Only listen on localhost. This is to prevent
+            # exposing the host port to the internet
+            '--publish',
+            f'127.0.0.1:{host_port}:{container_port}',
+            '--network',
+            network_name,
+            '--ip',
+            container_ip,
+            '--volume',
+            f'{volume_name}:/var/www/html',
+            '--name',
+            container_name,
+            '--restart',
+            'unless-stopped',
+            '--quiet',
+            # enable automatic updates
+            '--label',
+            'io.containers.autoupdate=registry',
+            # If another container with the same name already
+            # exists, replace and remove it.
+            '--replace',
+        ] + (extra_run_options or []) + [image_name]
+        subprocess.run(run_command, check=True)
+
+        systemd_content = subprocess.run(
+            ['podman', 'generate', 'systemd', '--new', container_name],
+            capture_output=True, check=True).stdout.decode()
+        pathlib.Path('/etc/systemd/system/'
+                     '{container_name}.service').write_text(
+                         systemd_content, encoding='utf-8')
+        service_daemon_reload()
+
+
+def podman_uninstall(container_name, network_name, volume_name, image_name):
+    """Remove a podman container's components and systemd unit."""
+    components = [('network', network_name), ('volume', volume_name),
+                  ('image', image_name)]
+    for component in components:
+        subprocess.run(['podman', component[0], 'rm', component[1]],
+                       check=True)
+    pathlib.Path('/etc/systemd/system/{container_name}.service').unlink(
+        missing_ok=True)
+    service_daemon_reload()
