@@ -1,6 +1,7 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
 """Component for managing a background daemon or any systemd unit."""
 
+import contextlib
 import socket
 import subprocess
 
@@ -8,13 +9,17 @@ import psutil
 from django.utils.translation import gettext_noop
 
 from plinth import action_utils, app
+from plinth.diagnostic_check import (DiagnosticCheck,
+                                     DiagnosticCheckParameters, Result)
 
 
 class Daemon(app.LeaderComponent):
     """Component to manage a background daemon or any systemd unit."""
 
-    def __init__(self, component_id, unit, strict_check=False,
-                 listen_ports=None, alias=None):
+    def __init__(self, component_id: str, unit: str,
+                 strict_check: bool = False,
+                 listen_ports: list[tuple[int, str]] | None = None,
+                 alias: str | None = None):
         """Initialize a new daemon component.
 
         'component_id' must be a unique string across all apps and components
@@ -82,7 +87,21 @@ class Daemon(app.LeaderComponent):
         """Return whether the daemon/unit is running."""
         return action_utils.service_is_running(self.unit)
 
-    def diagnose(self):
+    @contextlib.contextmanager
+    def ensure_running(self):
+        """Ensure a service is running and return to previous state."""
+        from plinth.privileged import service as service_privileged
+        starting_state = self.is_running()
+        if not starting_state:
+            service_privileged.enable(self.unit)
+
+        try:
+            yield starting_state
+        finally:
+            if not starting_state:
+                service_privileged.disable(self.unit)
+
+    def diagnose(self) -> list[DiagnosticCheck]:
         """Check if the daemon is running and listening on expected ports.
 
         See :py:meth:`plinth.app.Component.diagnose`.
@@ -95,15 +114,15 @@ class Daemon(app.LeaderComponent):
 
         return results
 
-    def _diagnose_unit_is_running(self):
+    def _diagnose_unit_is_running(self) -> DiagnosticCheck:
         """Check if a daemon is running."""
-        from plinth.modules.diagnostics.check import DiagnosticCheck, Result
-
         check_id = f'daemon-running-{self.unit}'
         result = Result.PASSED if self.is_running() else Result.FAILED
 
         description = gettext_noop('Service {service_name} is running')
-        parameters = {'service_name': self.unit}
+        parameters: DiagnosticCheckParameters = {
+            'service_name': str(self.unit)
+        }
 
         return DiagnosticCheck(check_id, description, result, parameters)
 
@@ -135,6 +154,41 @@ class RelatedDaemon(app.FollowerComponent):
         self.unit = unit
 
 
+class SharedDaemon(Daemon):
+    """Component to manage a daemon that is used by multiple apps.
+
+    Daemons such as a database server are a hard requirement for an app.
+    However, there may be multiple apps using that server. This component
+    ensures that server is enabled and running when app is enabled. It runs
+    diagnostics on the daemon when app is diagnosed. The primary difference
+    from the Daemon component is that when the app is disabled the daemon must
+    only be disabled if there is no other app using this daemon.
+    """
+
+    # A shared daemon may be running even when an app is disabled because
+    # another app might be using the daemon. Hence, the enabled/disabled state
+    # of this component can't be used to determine the enabled/disabled state
+    # of the app.
+    is_leader = False
+
+    def set_enabled(self, enabled):
+        """Do nothing. Enabled state is still determined by unit status."""
+
+    def disable(self):
+        """Disable the daemon iff this is the last app using the daemon."""
+        other_apps_enabled = False
+        for other_app in app.App.list():
+            if other_app.app_id == self.app_id:
+                continue
+
+            for component in other_app.get_components_of_type(SharedDaemon):
+                if component.unit == self.unit and other_app.is_enabled():
+                    other_apps_enabled = True
+
+        if not other_apps_enabled:
+            super().disable()
+
+
 def app_is_running(app_):
     """Return whether all the daemons in the app are running."""
     for component in app_.components.values():
@@ -144,7 +198,9 @@ def app_is_running(app_):
     return True
 
 
-def diagnose_port_listening(port, kind='tcp', listen_address=None):
+def diagnose_port_listening(
+        port: int, kind: str = 'tcp',
+        listen_address: str | None = None) -> DiagnosticCheck:
     """Run a diagnostic on whether a port is being listened on.
 
     Kind must be one of inet, inet4, inet6, tcp, tcp4, tcp6, udp,
@@ -152,11 +208,9 @@ def diagnose_port_listening(port, kind='tcp', listen_address=None):
     information.
 
     """
-    from plinth.modules.diagnostics.check import DiagnosticCheck, Result
-
     result = _check_port(port, kind, listen_address)
 
-    parameters = {'kind': kind, 'port': port}
+    parameters: DiagnosticCheckParameters = {'kind': kind, 'port': port}
     if listen_address:
         parameters['listen_address'] = listen_address
         check_id = f'daemon-listening-address-{kind}-{port}-{listen_address}'
@@ -171,7 +225,8 @@ def diagnose_port_listening(port, kind='tcp', listen_address=None):
                            parameters)
 
 
-def _check_port(port, kind='tcp', listen_address=None):
+def _check_port(port: int, kind: str = 'tcp',
+                listen_address: str | None = None) -> bool:
     """Return whether a port is being listened on."""
     run_kind = kind
 
@@ -193,11 +248,12 @@ def _check_port(port, kind='tcp', listen_address=None):
             continue
 
         # Port should match
-        if connection.laddr[1] != port:
+        if connection.laddr[1] != port:  # type: ignore[misc]
             continue
 
         # Listen address if requested should match
-        if listen_address and connection.laddr[0] != listen_address:
+        if listen_address and connection.laddr[
+                0] != listen_address:  # type: ignore[misc]
             continue
 
         # Special additional checks only for IPv4
@@ -209,22 +265,21 @@ def _check_port(port, kind='tcp', listen_address=None):
             return True
 
         # Full IPv6 address range includes mapped IPv4 address also
-        if connection.laddr[0] == '::':
+        if connection.laddr[0] == '::':  # type: ignore[misc]
             return True
 
     return False
 
 
-def diagnose_netcat(host, port, input='', negate=False):
+def diagnose_netcat(host: str, port: int, remote_input: str = '',
+                    negate: bool = False) -> DiagnosticCheck:
     """Run a diagnostic using netcat."""
-    from plinth.modules.diagnostics.check import DiagnosticCheck, Result
-
     try:
         process = subprocess.Popen(['nc', host, str(port)],
                                    stdin=subprocess.PIPE,
                                    stdout=subprocess.PIPE,
                                    stderr=subprocess.PIPE)
-        process.communicate(input=input.encode())
+        process.communicate(input=remote_input.encode())
         if process.returncode != 0:
             result = Result.FAILED if not negate else Result.PASSED
         else:
@@ -234,10 +289,13 @@ def diagnose_netcat(host, port, input='', negate=False):
 
     check_id = f'daemon-netcat-{host}-{port}'
     description = gettext_noop('Connect to {host}:{port}')
-    parameters = {'host': host, 'port': port, 'negate': negate}
+    parameters: DiagnosticCheckParameters = {
+        'host': host,
+        'port': port,
+        'negate': negate
+    }
     if negate:
         check_id = f'daemon-netcat-negate-{host}-{port}'
         description = gettext_noop('Cannot connect to {host}:{port}')
 
-    return DiagnosticCheck(check_id, description.format(host=host, port=port),
-                           result, parameters)
+    return DiagnosticCheck(check_id, description, result, parameters)
