@@ -32,7 +32,8 @@ def _collect_operations_results(request, app):
     operations = operation_module.manager.collect_results(app.app_id)
     for operation in operations:
         if operation.exception:
-            messages.error(request, operation.message)
+            views.messages_error(request, operation.message,
+                                 operation.exception)
         else:
             messages.success(request, operation.message)
 
