@@ -59,9 +59,8 @@ def fixture_create_temp_user(temp_home, password, needs_root):
     subprocess.check_call(['sudo', 'userdel', username])
 
 
-@pytest.mark.usefixtures('needs_sudo')
 @pytest.fixture(name='has_ssh_key', scope='module', autouse=True)
-def fixture_ssh_key(temp_home, temp_user, password, needs_root):
+def fixture_ssh_key(temp_home, temp_user, password, needs_root, needs_sudo):
     subprocess.check_call([
         'sudo', '-n', '-u', temp_user, 'ssh-keygen', '-t', 'rsa', '-b', '1024',
         '-N', '', '-f', f'{temp_home}/.ssh/id_rsa', '-q'
@@ -110,7 +109,8 @@ def test_add_repository_when_directory_exists_and_not_empty(
         temp_user, temp_home, password):
     remote_path = os.path.join(temp_home, 'non_empty_dir')
     os.makedirs(remote_path)
-    open(os.path.join(remote_path, 'somefile.txt'), 'w').close()
+    open(os.path.join(remote_path, 'somefile.txt'), 'w',
+         encoding='utf-8').close()
     data = {
         'repository': f'{temp_user}@localhost:{remote_path}',
         'ssh_password': password,
