@@ -20,12 +20,12 @@ from django.utils.translation import gettext as _
 from django.utils.translation import gettext_lazy
 from django.views.generic import FormView, TemplateView, View
 
-from plinth import app as app_module
 from plinth.errors import PlinthError
 from plinth.modules import backups, storage
+from plinth.views import AppView
 
 from . import (SESSION_PATH_VARIABLE, api, forms, get_known_hosts_path,
-               is_ssh_hostkey_verified)
+               is_ssh_hostkey_verified, privileged)
 from .decorators import delete_tmp_backup_file
 from .repository import (BorgRepository, SshBorgRepository, get_instance,
                          get_repositories)
@@ -34,14 +34,15 @@ logger = logging.getLogger(__name__)
 
 
 @method_decorator(delete_tmp_backup_file, name='dispatch')
-class IndexView(TemplateView):
+class BackupsView(AppView):
     """View to show list of archives."""
+
+    app_id = 'backups'
     template_name = 'backups.html'
 
     def get_context_data(self, **kwargs):
         """Return additional context for rendering the template."""
         context = super().get_context_data(**kwargs)
-        context['app_info'] = app_module.App.get('backups').info
         context['repositories'] = [
             repository.get_view_content() for repository in get_repositories()
         ]
@@ -49,9 +50,11 @@ class IndexView(TemplateView):
 
 
 class ScheduleView(SuccessMessageMixin, FormView):
+    """View to edit a backup schedule."""
+
     form_class = forms.ScheduleForm
     prefix = 'backups_schedule'
-    template_name = 'backups_schedule.html'
+    template_name = 'form.html'
     success_url = reverse_lazy('backups:index')
     success_message = gettext_lazy('Backup schedule updated.')
 
@@ -100,9 +103,10 @@ class ScheduleView(SuccessMessageMixin, FormView):
 
 class CreateArchiveView(SuccessMessageMixin, FormView):
     """View to create a new archive."""
+
     form_class = forms.CreateArchiveForm
     prefix = 'backups'
-    template_name = 'backups_form.html'
+    template_name = 'form.html'
     success_url = reverse_lazy('backups:index')
     success_message = gettext_lazy('Archive created.')
 
@@ -112,6 +116,14 @@ class CreateArchiveView(SuccessMessageMixin, FormView):
         context['title'] = _('Create a new backup')
         return context
 
+    def get_initial(self):
+        """Return initialization arguments to the form."""
+        initial = super().get_initial()
+        if 'app_id' in self.kwargs:
+            initial['selected_apps'] = [self.kwargs['app_id']]
+
+        return initial
+
     def form_valid(self, form):
         """Create the archive on valid form submission."""
         repository = get_instance(form.cleaned_data['repository'])
@@ -234,7 +246,7 @@ class RestoreFromUploadView(BaseRestoreView):
     def _get_included_apps(self):
         """Save some data used to instantiate the form."""
         path = self.request.session.get(SESSION_PATH_VARIABLE)
-        return backups.get_exported_archive_apps(path)
+        return privileged.get_exported_archive_apps(path)
 
     def form_valid(self, form):
         """Restore files from the archive on valid form submission."""
