@@ -4,6 +4,7 @@ Functional, browser based tests for config app.
 """
 
 import pytest
+
 from plinth.tests import functional
 
 pytestmark = [
@@ -20,7 +21,7 @@ def fixture_background(session_browser):
 
 def test_change_hostname(session_browser):
     """Test changing the hostname."""
-    _set_hostname(session_browser, 'mybox')
+    functional.set_hostname(session_browser, 'mybox')
     assert _get_hostname(session_browser) == 'mybox'
 
 
@@ -49,13 +50,6 @@ def _get_hostname(browser):
     return browser.find_by_id('id_hostname').value
 
 
-def _set_hostname(browser, hostname):
-    functional.nav_to_module(browser, 'config')
-    browser.find_by_id('id_hostname').fill(hostname)
-    update_setup = browser.find_by_css('.btn-primary')
-    functional.submit(browser, element=update_setup)
-
-
 def _get_domain_name(browser):
     functional.nav_to_module(browser, 'config')
     return browser.find_by_id('id_domainname').value
@@ -68,8 +62,7 @@ def _set_home_page(browser, home_page):
     functional.nav_to_module(browser, 'config')
     drop_down = browser.find_by_id('id_homepage')
     drop_down.select(home_page)
-    update_setup = browser.find_by_css('.btn-primary')
-    functional.submit(browser, element=update_setup)
+    functional.submit(browser, form_class='form-configuration')
 
 
 def _check_home_page_redirect(browser, app_name):
