@@ -37,7 +37,7 @@ class IkiwikiApp(app_module.App):
 
     _version = 2
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
