@@ -35,7 +35,7 @@ class JanusApp(app_module.App):
 
     _version = 2
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
