@@ -46,7 +46,7 @@ class MatrixSynapseApp(app_module.App):
 
     _version = 10
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
