@@ -3,7 +3,7 @@
 Application manifest for OpenVPN.
 """
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.clients import store_url
 
@@ -33,6 +33,11 @@ clients = [{
         'os': 'android',
         'store_name': 'google-play',
         'url': store_url('google-play', _package_id)
+    }, {
+        'type': 'store',
+        'os': 'ios',
+        'store_name': 'app-store',
+        'url': 'https://apps.apple.com/app/openvpn-connect/id590379981'
     }, {
         'type': 'download',
         'os': 'gnu-linux',
