@@ -43,7 +43,7 @@ class QuasselApp(app_module.App):
 
     _version = 1
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
