@@ -31,7 +31,7 @@ class SearxApp(app_module.App):
 
     _version = 6
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
