@@ -42,7 +42,7 @@ class ShadowsocksApp(app_module.App):
 
     DAEMON = 'shadowsocks-libev-local@freedombox'
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
