@@ -27,7 +27,7 @@ class SharingApp(app_module.App):
 
     _version = 3
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
         info = app_module.Info(app_id=self.app_id, version=self._version,
