@@ -47,7 +47,7 @@ class SyncthingApp(app_module.App):
 
     DAEMON = 'syncthing@syncthing'
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
