@@ -4,6 +4,8 @@ from django.utils.translation import gettext_lazy as _
 
 from plinth.clients import store_url
 
+from . import privileged
+
 _orbot_package_id = 'org.torproject.android'
 _tor_browser_download_url = \
     'https://www.torproject.org/download/download-easy.html'
@@ -42,10 +44,11 @@ clients = [{
 
 backup = {
     'config': {
-        'directories': ['/etc/tor/']
+        'directories': ['/etc/tor/instances/plinth/'],
+        'files': [str(privileged.TOR_APACHE_SITE)]
     },
     'secrets': {
-        'directories': ['/var/lib/tor/', '/var/lib/tor-instances/']
+        'directories': ['/var/lib/tor-instances/plinth/']
     },
     'services': ['tor@plinth']
 }
