@@ -65,8 +65,9 @@ def test_create_user(session_browser):
     if functional.user_exists(session_browser, 'alice'):
         functional.delete_user(session_browser, 'alice')
 
-    functional.create_user(session_browser, 'alice')
+    functional.create_user(session_browser, 'alice', email='alice@example.com')
     assert functional.user_exists(session_browser, 'alice')
+    assert _get_email(session_browser, 'alice') == 'alice@example.com'
 
 
 def test_rename_user(session_browser):
@@ -133,6 +134,17 @@ def test_users_cannot_connect_passwordless_over_ssh(session_browser,
                                               tmp_path_factory)
 
 
+def test_update_user(session_browser):
+    """Test changing properties of a user."""
+    functional.create_user(session_browser, 'alice', email='alice@example.com')
+
+    # Update email
+    _set_email(session_browser, 'alice', 'alice1@example.com')
+    assert _get_email(session_browser, 'alice') == 'alice1@example.com'
+    _set_email(session_browser, 'alice', 'alice2@example.com')
+    assert _get_email(session_browser, 'alice') == 'alice2@example.com'
+
+
 @pytest.mark.parametrize('language_code', _language_codes.values())
 def test_change_language(session_browser, language_code):
     """Test changing the language."""
@@ -251,7 +263,21 @@ def _rename_user(browser, old_name, new_name):
                                    '/edit/').first.click()
     browser.find_by_id('id_username').fill(new_name)
     browser.find_by_id('id_confirm_password').fill(_admin_password)
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-update')
+
+
+def _set_email(browser, username, email):
+    """Set the email field value for a user."""
+    functional.visit(browser, '/plinth/sys/users/{}/edit/'.format(username))
+    browser.find_by_id('id_email').fill(email)
+    browser.find_by_id('id_confirm_password').fill(_admin_password)
+    functional.submit(browser, form_class='form-update')
+
+
+def _get_email(browser, username):
+    """Return the email field value for a user."""
+    functional.visit(browser, '/plinth/sys/users/{}/edit/'.format(username))
+    return browser.find_by_id('id_email').value
 
 
 def _set_language(browser, language_code):
@@ -260,7 +286,7 @@ def _set_language(browser, language_code):
     browser.find_by_xpath('//select[@id="id_language"]//option[@value="' +
                           language_code + '"]').first.click()
     browser.find_by_id('id_confirm_password').fill(_admin_password)
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-update')
 
 
 def _check_language(browser, language_code):
@@ -294,14 +320,14 @@ def _set_ssh_keys(browser, ssh_keys, username=None):
     browser.find_by_id('id_ssh_keys').fill(ssh_keys)
     browser.find_by_id('id_confirm_password').fill(auth_password)
 
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-update')
 
 
 def _set_user_inactive(browser, username):
     functional.visit(browser, '/plinth/sys/users/{}/edit/'.format(username))
     browser.find_by_id('id_is_active').uncheck()
     browser.find_by_id('id_confirm_password').fill(_admin_password)
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-update')
 
 
 def _change_password(browser, new_password, current_password=None,
@@ -319,7 +345,7 @@ def _change_password(browser, new_password, current_password=None,
     browser.find_by_id('id_new_password1').fill(new_password)
     browser.find_by_id('id_new_password2').fill(new_password)
     browser.find_by_id('id_confirm_password').fill(auth_password)
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-change-password')
 
 
 def _try_login_to_ssh(key_file=None):
