@@ -8,6 +8,7 @@ from django.utils.translation import gettext_lazy as _
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.config import DropinConfigs
+from plinth.daemon import SharedDaemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.backups.components import BackupRestore
 from plinth.modules.firewall.components import Firewall
@@ -45,7 +46,9 @@ class ZophApp(app_module.App):
 
     _version = 2
 
-    def __init__(self):
+    configure_when_disabled = False
+
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
@@ -89,6 +92,9 @@ class ZophApp(app_module.App):
         webserver = Webserver('webserver-zoph-freedombox', 'zoph-freedombox')
         self.add(webserver)
 
+        daemon = SharedDaemon('shared-daemon-zoph-mysql', 'mysql')
+        self.add(daemon)
+
         backup_restore = ZophBackupRestore('backup-restore-zoph',
                                            **manifest.backup)
         self.add(backup_restore)
@@ -96,7 +102,11 @@ class ZophApp(app_module.App):
     def setup(self, old_version):
         """Install and configure the app."""
         privileged.pre_install()
-        super().setup(old_version)
+        with self.get_component('shared-daemon-zoph-mysql').ensure_running():
+            # Database needs to be running for successful initialization or
+            # upgrade of zoph database.
+            super().setup(old_version)
+
         privileged.setup()
         if not old_version:
             self.enable()
@@ -104,6 +114,12 @@ class ZophApp(app_module.App):
             if self.get_component('webserver-zoph').is_enabled():
                 self.enable()
 
+    def uninstall(self):
+        """De-configure and uninstall the app."""
+        # Before package uninstall, so that config file is still available
+        privileged.uninstall()
+        super().uninstall()
+
 
 class ZophBackupRestore(BackupRestore):
     """Component to backup/restore Zoph database"""
