@@ -33,12 +33,10 @@ CONNECTION_TYPE_NAMES = collections.OrderedDict([
 
 class ConnectionNotFound(Exception):
     """Network connection with a given name could not be found."""
-    pass
 
 
 class DeviceNotFound(Exception):
     """Network device for specified operation could not be found."""
-    pass
 
 
 def ipv4_string_to_int(address):
@@ -111,7 +109,9 @@ def get_status_from_connection(connection):
 
     if status['type'] == '802-11-wireless':
         setting_wireless = connection.get_setting_wireless()
-        status['wireless']['ssid'] = setting_wireless.get_ssid().get_data()
+        status['wireless']['ssid'] = setting_wireless.get_ssid().get_data(
+        ).decode()
+        status['wireless']['mode'] = setting_wireless.get_mode()
 
     return status
 
@@ -228,6 +228,11 @@ def get_connection_list():
     for connection in client.get_connections():
         # Display a friendly type name if known.
         connection_type = connection.get_connection_type()
+        # Do not show bridge adapter as it is not meant to
+        # be modified by the user.
+        if connection_type == 'bridge':
+            continue
+
         connection_type_name = CONNECTION_TYPE_NAMES.get(
             connection_type, connection_type)
 
