@@ -1,7 +1,5 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
-"""
-Module to provide API for showing notifications.
-"""
+"""Module to provide API for showing notifications."""
 
 import copy
 import logging
@@ -13,8 +11,9 @@ from django.template.response import SimpleTemplateResponse
 from django.utils.translation import gettext
 
 from plinth import cfg
+from plinth.utils import SafeFormatter
 
-from . import models
+from . import db, models
 
 severities = {'exception': 5, 'error': 4, 'warning': 3, 'info': 2, 'debug': 1}
 logger = logging.getLogger(__name__)
@@ -177,7 +176,8 @@ class Notification(models.StoredNotification):
 
         """
         self.dismissed = should_dismiss
-        super().save()
+        with db.lock:
+            super().save()
 
     def clean(self):
         """Perform additional validations on the model."""
@@ -229,16 +229,19 @@ class Notification(models.StoredNotification):
 
         """
         id = kwargs.pop('id')
-        return Notification.objects.update_or_create(defaults=kwargs, id=id)[0]
+        with db.lock:
+            return Notification.objects.update_or_create(
+                defaults=kwargs, id=id)[0]
 
     @staticmethod
     def get(key):  # pylint: disable=redefined-builtin
         """Return a notification object with a matching ID."""
         # pylint: disable=no-member
-        try:
-            return Notification.objects.get(pk=key)
-        except Notification.DoesNotExist:
-            raise KeyError('No such notification')
+        with db.lock:
+            try:
+                return Notification.objects.get(pk=key)
+            except Notification.DoesNotExist:
+                raise KeyError('No such notification')
 
     @staticmethod
     def list(key=None, app_id=None, user=None, dismissed=False):
@@ -275,25 +278,26 @@ class Notification(models.StoredNotification):
         if dismissed is not None:
             filters.append(Q(dismissed=dismissed))
 
-        return Notification.objects.filter(*filters)[0:10]
+        with db.lock:
+            return Notification.objects.filter(*filters)[0:10]
 
     @staticmethod
-    def _translate(string, data=None):
+    def _translate(string_, data=None):
         """Translate a string for final display using data dict."""
-        if not string:
+        if not string_:
             return None
 
-        string = gettext(string)
+        string_ = gettext(string_)
         try:
-            string = str(string)
+            string_ = str(string_)
             if data:
-                string = string.format(**data)
+                string_ = SafeFormatter().vformat(string_, [], data)
         except KeyError as error:
             logger.warning(
                 'Notification missing required key during translation: %s',
                 error)
 
-        return string
+        return string_
 
     @staticmethod
     def _translate_dict(data_dict, data=None):
