@@ -13,7 +13,7 @@ from django.utils.translation import gettext_noop
 
 import plinth
 from plinth import app as app_module
-from plinth.package import PackageException, Packages
+from plinth.package import Packages
 from plinth.signals import post_setup
 
 from . import operation as operation_module
@@ -26,8 +26,6 @@ _is_first_setup = False
 is_first_setup_running = False
 _is_shutting_down = False
 
-_force_upgrader = None
-
 
 def run_setup_on_app(app_id, allow_install=True, rerun=False):
     """Execute the setup process in a thread."""
@@ -59,21 +57,18 @@ def _run_setup_on_app(app, current_version):
     message = None
     try:
         current_version = app.get_setup_version()
+
+        if current_version != 0:
+            # Check if this app needs force_upgrade. If it is needed, but not
+            # yet supported for the new version of the package, then an
+            # exception will be raised, so that we do not run setup.
+            package.refresh_package_lists()
+            force_upgrader = ForceUpgrader.get_instance()
+            force_upgrader.attempt_upgrade_for_app(app.app_id)
+
         app.setup(old_version=current_version)
         app.set_setup_version(app.info.version)
         post_setup.send_robust(sender=app.__class__, module_name=app.app_id)
-    except PackageException as exception:
-        exception_to_update = exception
-        error_string = getattr(exception, 'error_string', str(exception))
-        error_details = getattr(exception, 'error_details', '')
-        if not current_version:
-            message = gettext_noop('Error installing app: {string} '
-                                   '{details}').format(string=error_string,
-                                                       details=error_details)
-        else:
-            message = gettext_noop('Error updating app: {string} '
-                                   '{details}').format(string=error_string,
-                                                       details=error_details)
     except Exception as exception:
         exception_to_update = exception
         if not current_version:
@@ -117,14 +112,6 @@ def _run_uninstall_on_app(app):
         app.disable()
         app.uninstall()
         app.set_setup_version(0)
-    except PackageException as exception:
-        exception_to_update = exception
-        error_string = getattr(exception, 'error_string', str(exception))
-        error_details = getattr(exception, 'error_details', '')
-        message = gettext_noop('Error uninstalling app: {string} '
-                               '{details}').format(string=error_string,
-                                                   details=error_details)
-
     except Exception as exception:
         exception_to_update = exception
         message = gettext_noop('Error uninstalling app: {error}').format(
@@ -143,8 +130,8 @@ def stop():
     global _is_shutting_down
     _is_shutting_down = True
 
-    if _force_upgrader:
-        _force_upgrader.shutdown()
+    force_upgrader = ForceUpgrader.get_instance()
+    force_upgrader.shutdown()
 
 
 def setup_apps(app_ids=None, essential=False, allow_install=True):
@@ -229,8 +216,8 @@ def _get_apps_for_regular_setup():
         1. essential apps that are not up-to-date
         2. non-essential app that are installed and need updates
         """
-        if (app.info.is_essential and
-                app.get_setup_state() != app_module.App.SetupState.UP_TO_DATE):
+        if (app.info.is_essential and app.get_setup_state()
+                != app_module.App.SetupState.UP_TO_DATE):
             return True
 
         if app.get_setup_state() == app_module.App.SetupState.NEEDS_UPDATE:
@@ -335,6 +322,7 @@ class ForceUpgrader():
 
     """
 
+    _instance = None
     _run_lock = threading.Lock()
     _wait_event = threading.Event()
 
@@ -349,6 +337,14 @@ class ForceUpgrader():
         """Raised when upgrade fails and there is nothing more we wish to do.
         """
 
+    @classmethod
+    def get_instance(cls):
+        """Return a single instance of a the class."""
+        if not cls._instance:
+            cls._instance = ForceUpgrader()
+
+        return cls._instance
+
     def __init__(self):
         """Initialize the force upgrader."""
         if plinth.cfg.develop:
@@ -401,7 +397,7 @@ class ForceUpgrader():
     def shutdown(self):
         """If we are sleeping for next attempt, cancel it.
 
-        If we are actually upgrading packages, don nothing.
+        If we are actually upgrading packages, do nothing.
         """
         self._wait_event.set()
 
@@ -448,6 +444,50 @@ class ForceUpgrader():
         if need_retry:
             raise self.TemporaryFailure('Some apps failed to force upgrade.')
 
+    def attempt_upgrade_for_app(self, app_id):
+        """Attempt to perform an upgrade for specified app.
+
+        Raise TemporaryFailure if upgrade can't be performed now.
+
+        Raise PermanentFailure if upgrade can't be performed until something
+        with the system state changes. We don't want to try again until
+        notified of further package cache changes.
+
+        Return True if upgrade was performed successfully.
+
+        Return False if upgrade is not needed.
+
+        """
+        if _is_shutting_down:
+            raise self.PermanentFailure('Service is shutting down')
+
+        if packages_privileged.is_package_manager_busy():
+            raise self.TemporaryFailure('Package manager is busy')
+
+        apps = self._get_list_of_apps_to_force_upgrade()
+        if app_id not in apps:
+            logger.info('App %s does not need force upgrade', app_id)
+            return False
+
+        packages = apps[app_id]
+        app = app_module.App.get(app_id)
+        try:
+            logger.info('Force upgrading app: %s', app.info.name)
+            if app.force_upgrade(packages):
+                logger.info('Successfully force upgraded app: %s',
+                            app.info.name)
+                return True
+            else:
+                logger.warning('Ignored force upgrade for app: %s',
+                               app.info.name)
+                raise self.TemporaryFailure(
+                    'Force upgrade is needed, but not yet implemented for new '
+                    f'version of app: {app_id}')
+        except Exception as exception:
+            logger.exception('Error running force upgrade: %s', exception)
+            raise self.TemporaryFailure(
+                f'App {app_id} failed to force upgrade.')
+
     def _run_force_upgrade_as_operation(self, app, packages):
         """Start an operation for force upgrading."""
         name = gettext_noop('Updating app packages')
@@ -523,8 +563,5 @@ class ForceUpgrader():
 
 def on_package_cache_updated():
     """Called by D-Bus service when apt package cache is updated."""
-    global _force_upgrader
-    if not _force_upgrader:
-        _force_upgrader = ForceUpgrader()
-
-    _force_upgrader.on_package_cache_updated()
+    force_upgrader = ForceUpgrader.get_instance()
+    force_upgrader.on_package_cache_updated()
