@@ -8,10 +8,11 @@ from unittest.mock import MagicMock, Mock
 
 import pytest
 import ruamel.yaml
-from ruamel.yaml.compat import StringIO
 from django.test.client import RequestFactory
+from ruamel.yaml.compat import StringIO
 
-from plinth.utils import YAMLFile, is_user_admin, is_valid_user_name
+from plinth.utils import (SafeFormatter, YAMLFile, is_user_admin,
+                          is_valid_user_name)
 
 
 def test_is_valid_user_name():
@@ -92,7 +93,7 @@ class TestYAMLFileUtil:
     kv_pair = {'key': 'value'}
 
     yaml = ruamel.yaml.YAML()
-    yaml.preserve_quotes = True
+    yaml.preserve_quotes = True  # type: ignore [assignment]
 
     def test_update_empty_yaml_file(self):
         """
@@ -105,7 +106,7 @@ class TestYAMLFileUtil:
             for key in conf:
                 file_conf[key] = conf[key]
 
-        with open(test_file.name, 'r') as retrieved_conf:
+        with open(test_file.name, 'r', encoding='utf-8') as retrieved_conf:
             buffer = StringIO()
             self.yaml.dump(conf, buffer)
             assert retrieved_conf.read() == buffer.getvalue()
@@ -116,13 +117,13 @@ class TestYAMLFileUtil:
         """
         test_file = tempfile.NamedTemporaryFile()
 
-        with open(test_file.name, 'w') as conf_file:
+        with open(test_file.name, 'w', encoding='utf-8') as conf_file:
             self.yaml.dump({'property1': self.kv_pair}, conf_file)
 
         with YAMLFile(test_file.name) as file_conf:
             file_conf['property2'] = self.kv_pair
 
-        with open(test_file.name, 'r') as retrieved_conf:
+        with open(test_file.name, 'r', encoding='utf-8') as retrieved_conf:
             file_conf = self.yaml.load(retrieved_conf)
             assert file_conf == {
                 'property1': self.kv_pair,
@@ -138,4 +139,18 @@ class TestYAMLFileUtil:
                 yaml_file['property1'] = 'value1'
                 raise ValueError('Test')
 
-        assert open(test_file.name, 'r').read() == ''
+        assert open(test_file.name, 'r', encoding='utf-8').read() == ''
+
+
+@pytest.mark.parametrize('input_, output', (
+    (('', [], {}), ''),
+    (('{} {}', [10, 20], {}), '10 20'),
+    (('{1} {0} {key1}', [10, 20], {
+        'key1': 'value1'
+    }), '20 10 value1'),
+    (('{2} {1} {key1}', [10, 20], {}), '?2? 20 ?key1?'),
+))
+def test_safe_string_formatter(input_, output):
+    """Test the safe string formatter."""
+    formatter = SafeFormatter()
+    assert output == formatter.vformat(*input_)
