@@ -3,11 +3,20 @@
 Django URLconf file containing all urls
 """
 from captcha import views as cviews
-from django.urls import re_path
+from django.urls import include, re_path
 from stronghold.decorators import public
 
 from . import views
 
+system_urlpatterns = [
+    re_path(r'^sys/#visibility$', views.system_index, name='visibility'),
+    re_path(r'^sys/#data$', views.system_index, name='data'),
+    re_path(r'^sys/#system$', views.system_index, name='system'),
+    re_path(r'^sys/#security$', views.system_index, name='security'),
+    re_path(r'^sys/#administration$', views.system_index,
+            name='administration'),
+]
+
 urlpatterns = [
     re_path(r'^$', views.index, name='index'),
     re_path(r'^language-selection/$',
@@ -15,6 +24,7 @@ urlpatterns = [
             name='language-selection'),
     re_path(r'^apps/$', views.AppsIndexView.as_view(), name='apps'),
     re_path(r'^sys/$', views.system_index, name='system'),
+    re_path(r'', include((system_urlpatterns, 'system'))),
     re_path(r'^uninstall/(?P<app_id>[1-9a-z\-_]+)/$',
             views.UninstallView.as_view(), name='uninstall'),
     re_path(r'^rerun-setup/(?P<app_id>[1-9a-z\-_]+)/$', views.rerun_setup_view,
